@@ -1,20 +1,23 @@
 import os
 
-def printfile(x):
-  f=open(x,"r")
-  user_pass=f.read()
-  print(user_pass)
-  f.close()
+def printfile(name):
+  try:
+    f=open(name,"r")
+    user_pass=f.read()
+    print(user_pass)
+    f.close()
+  except:
+    print("file '%s' not found." % name)
 
 printfile("wifiman.conf")
-yn=input("delete all existing WiFi users:passwords (y/n)? ")
+yn=input("create new and delete all WiFi users:passwords (n/y)? ")
 if yn.startswith("y"):
   f=open("wifiman.conf","w")
   f.close()
   print("all WiFi users:passwords deleted")
 yn="y"
 while yn.startswith("y"):
-  yn=input("add WiFi user:password (y/n)? ")
+  yn=input("add WiFi user:password (n/y)? ")
   if yn.startswith("y"):
     user_pass=input("enter WiFi user:password> ")
     f=open("wifiman.conf","a")
@@ -41,9 +44,10 @@ def main():
   )
   f.close()
 
-yn=input("overwrite 'main.py' to run FTP server at boot (y/n)? ")
+yn=input("overwrite 'main.py' to run FTP server at boot (n/y)? ")
 if yn.startswith("y"):
   main()
+  print("main.py overwritten")
 
 def pins_v20():
   f=open("jtagpin.py","w")
@@ -62,12 +66,12 @@ def pins_v31():
   f=open("jtagpin.py","w")
   f.write(
 "# ULX3S v3.1.x\n"
-"tms=const(21)\n"
+"tms=const(5)\n"
 "tck=const(18)\n"
 "tdi=const(23)\n"
-"tdo=const(19)\n"
-"tcknc=const(17)\n"
-"led=const(5)\n"
+"tdo=const(34)\n"
+"tcknc=const(21)\n"
+"led=const(19)\n"
   )
   f.close()
 
@@ -84,8 +88,8 @@ def pins_fjc():
   )
   f.close()
 
-
-yn=input("change JTAG pinout (y/n)? ")
+printfile("jtagpin.py")
+yn=input("change JTAG pinout (n/y)? ")
 if yn.startswith("y"):
   print("0: ULX3S v2.x.x or v3.0.x")
   print("1: ULX3S v3.1.x")
@@ -93,11 +97,8 @@ if yn.startswith("y"):
   pinout=input("select pinout (0-2)> ")
   if pinout.startswith("0"):
     pins_v20()
-    print("selected pinout: ULX3S v2.x.x or v3.0.x")
   if pinout.startswith("1"):
     pins_v31()
-    print("selected pinout: ULX3S v3.1.x")
   if pinout.startswith("2"):
     pins_fjc()
-    print("selected pinout: FJC-ESP32-V0r2")
   printfile("jtagpin.py")
